@@ -112,10 +112,12 @@ def create_qlr(filename, fileqlr="", cmapname=None):
         fill_color = "#ffffff"
         ext = justext(filename).lower()
 
+        metadata = GetMetaData(filename)
 
         # Redefine sand, silt, clay cmap
         if ext == "tif":
-            cmapname = cmapname if cmapname else GetTag(filename, "type")
+
+            cmapname = cmapname if cmapname else metadata["type"]
 
             filetpl = pkg_resources.resource_filename(__name__, "data/raster.qlr")
             if cmapname == "dtm":  # dtm
@@ -160,10 +162,10 @@ def create_qlr(filename, fileqlr="", cmapname=None):
                 items += f"""<item color="{item["color"]}" label="{item["label"]}" value="{item["value"]}" alpha="{item["alpha"]}"/>\n"""
         # Vector
         elif ext == "shp":
-            cmapname = cmapname if cmapname else GetTag(filename, "type")
+
+            cmapname = cmapname if cmapname else metadata["type"]
             geomtype = GetGeomTypeName(filename)
             filetpl = pkg_resources.resource_filename(__name__, f"data/{geomtype}.qlr")
-            metadata = {"type": cmapname}
 
             if cmapname == "infiltration_rate":
                 filetpl = pkg_resources.resource_filename(__name__, f"data/{cmapname}.qlr")
@@ -181,8 +183,6 @@ def create_qlr(filename, fileqlr="", cmapname=None):
             elif cmapname == "storagetank":
                 filetpl = pkg_resources.resource_filename(__name__, f"data/{cmapname}.qlr")
                 fill_color = "#127db9"
-            else:
-                metadata = {}
         else:
             return None
 
